package cd.casic.ci.log.api.impl;


import cd.casic.ci.log.dal.pojo.TaskBuildLogProperty;
import cd.casic.ci.log.dal.pojo.meta.Ansi;
import cd.casic.framework.commons.exception.ErrorCode;
import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.ci.log.api.BuildLogPrintResource;
import cd.casic.ci.log.dal.pojo.enums.LogStorageMode;
import cd.casic.ci.log.service.BuildLogPrintService;
import cd.casic.ci.log.service.IndexService;
import cd.casic.ci.log.service.LogStatusService;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.apache.logging.log4j.util.Strings;
import org.springframework.beans.factory.annotation.Value;
import cd.casic.ci.log.dal.pojo.message.LogMessage;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

@Slf4j
@RestController
public class BuildLogPrintResourceImpl implements BuildLogPrintResource {
    @Resource
    private BuildLogPrintService buildLogPrintService;
    @Resource
    private LogStatusService logStatusService;
    @Resource
    private IndexService indexService;

    @Value("{$spring.application.name}")
    private String applicationName;

    @Override
    public CommonResult<Boolean> addLogLine(String buildId, LogMessage logMessage) {
        if (Strings.isBlank(buildId)) {
            log.warn("Invalid build ID[" + buildId + "]");
            return CommonResult.error(new ErrorCode(1000, "buildId为空"));
        }
        ArrayList<LogMessage> list = new ArrayList<>();
        list.add(logMessage);
        //buildLogPrintService.dispatchEvent(new LogOriginEvent(buildId, list));
        System.out.println("占位");
        return CommonResult.success(true);
    }

    @Override
    public CommonResult<Boolean> addRedLogLine(String buildId, LogMessage logMessage) {
        if (Strings.isBlank(buildId)) {
            log.warn("Invalid build ID[" + buildId + "]");
            return CommonResult.error(new ErrorCode(1000, "buildId为空"));
        }
        // 设置红色日志
        List<LogMessage> list = new ArrayList<>();
        logMessage.setMessage(new Ansi().bold().fgRed().a(logMessage.getMessage()).reset().toString());
        list.add(logMessage);
        //buildLogPrintService.dispatchEvent(new LogOriginEvent(buildId,list));
        System.out.println("占位");
        return CommonResult.success(true);
    }

    @Override
    public CommonResult<Boolean> addYellowLogLine(String buildId, LogMessage logMessage) {
        if (Strings.isBlank(buildId)) {
            log.warn("Invalid build ID[" + buildId + "]");
            return CommonResult.error(new ErrorCode(1000, "buildId为空"));
        }
        // 设置黄色日志
        List<LogMessage> list = new ArrayList<>();
        logMessage.setMessage(new Ansi().bold().fgYellow().a(logMessage.getMessage()).reset().toString());
        list.add(logMessage);
        //buildLogPrintService.dispatchEvent(new LogOriginEvent(buildId,list));
        System.out.println("占位" + buildId + list);
        return CommonResult.success(true);
    }

    @Override
    public CommonResult<Boolean> addMultiLine(String buildId, List<LogMessage> logMessages) {
        if (Strings.isBlank(buildId)) {
            log.warn("Invalid build ID[" + buildId + "]");
            return CommonResult.error(new ErrorCode(1000, "buildId为空"));
        }
        //buildLogPrintService.dispatchEvent(new LogOriginEvent(buildId,logMessages));
        System.out.println("占位" + buildId + logMessages);
//        recordMultiLogCount(logMessages.size());
        return CommonResult.success(true);
    }

    @Override
    public CommonResult<Boolean> addLogStatus(String buildId, String tag, String subTag, String jobId, int executeCount, String logMode) {
        if (Strings.isBlank(buildId)) {
            log.warn("Invalid build ID[" + buildId + "]");
            return CommonResult.error(new ErrorCode(1000, "buildId为空"));
        }
        // #7168 通过一次获取创建记录以及缓存
        String index = indexService.getIndexName(buildId);
        log.info("Start to print log to index[" + index + "]");
        //buildLogPrintService.dispatchEvent(new LogStatusEvent(buildId,false,tag,subTag,jobId,executeCount, LogStorageMode.parse(logMode)));
        System.out.println("占位" + buildId + tag + subTag + jobId + executeCount + LogStorageMode.parse(logMode));
        return CommonResult.success(true);
    }

    @Override
    public CommonResult<Boolean> updateLogStatus(String buildId, boolean finished, String tag, String subTag, String jobId, int executeCount, String logMode) {
        if (Strings.isBlank(buildId)) {
            log.warn("Invalid build ID[" + buildId + "]");
            return CommonResult.error(new ErrorCode(1000, "buildId为空"));
        }
        //buildLogPrintService.dispatchEvent(new LogStatusEvent(buildId,finished,tag,subTag,jobId,executeCount,LogStorageMode.parse(logMode)));
        System.out.println("占位" + buildId + finished + tag + subTag + jobId + executeCount + LogStorageMode.parse(logMode));
        return CommonResult.success(true);
    }

    @Override
    public CommonResult<Boolean> updateLogStorageMode(String buildId, int executeCount, List<TaskBuildLogProperty> propertyList) {
        if (Strings.isBlank(buildId)) {
            log.warn("Invalid build ID[" + buildId + "]");
            return CommonResult.error(new ErrorCode(1000, "buildId为空"));
        }
        logStatusService.updateStorageMode(buildId, executeCount, propertyList);
        return CommonResult.success(true);
    }

}
