package cd.casic.ci.process.api.engine.pojo;

import cd.casic.ci.common.pipeline.enums.BuildStatus;
import cd.casic.ci.common.pipeline.enums.ChannelCode;
import cd.casic.ci.common.pipeline.pojo.BuildParameters;
import cd.casic.ci.common.pipeline.pojo.ErrorInfo;
import cd.casic.ci.process.api.process.pojo.BuildStageStatus;
import cd.casic.ci.process.api.process.pojo.PipelineBuildMaterial;
import cd.casic.ci.process.api.process.pojo.code.WebhookInfo;
import lombok.Data;
import org.apache.tomcat.jni.FileInfo;

import java.util.List;

/**
 * @author by mianbin
 * @Classname BuildInfo
 * @Description TODO
 * @Date 2025/3/31 16:36
 */
@Data
public class BuildInfo {
    private final String projectId;
    private final String pipelineId;
    private final String buildId;
    private final int version;
    private final String versionName;
    private final String yamlVersion;
    private final int buildNum;
    private final String trigger;
    private BuildStatus status;
    private long queueTime;
    private final long executeTime;
    // 真正用来执行构建的人的身份（一般像Git触发，有可能]与触发人不一样，因为Git平台账号不一定是人）
    private final String startUser;
    // 真正的触发人（不一定是人，也可能是机器账号，比如git平台账号）
    private final String triggerUser;
    private Long startTime;
    private Long endTime;
    private final int taskCount;
    private final String firstTaskId;
    private final String parentBuildId;
    private final String parentTaskId;
    private final ChannelCode channelCode;
    private List<BuildParameters> buildParameters;
    private List<ErrorInfo> errorInfoList;
    private List<BuildStageStatus> stageStatus;
    private final boolean debug;
    //只用executeCount做判断
    @Deprecated
    private final Boolean retryFlag;
    private final int executeCount;
    private String concurrencyGroup;
    private final String webhookType;
    private final WebhookInfo webhookInfo;
    private final String buildMsg;
    private final List<PipelineBuildMaterial> material;
    private final List<FileInfo> artifactList;
    private final String remark;
    private final String recommendVersion;
    private final String buildNumAlias;
    private final Long updateTime;
    private final Integer errorType;
    private final Integer errorCode;
    private final String errorMsg;

    public boolean isFinish() {
        if (status.name().equals(BuildStatus.STAGE_SUCCESS.name()) &&
                endTime != null &&
                endTime > 0 &&
                startTime != null &&
                endTime > startTime) {
            return true;
        }
        return status.isFinish();
    }

    public boolean isSuccess() {
        if (status.name().equals(BuildStatus.STAGE_SUCCESS.name()) &&
                endTime != null &&
                endTime > 0 &&
                startTime != null &&
                endTime > startTime) {
            return true;
        }
        return status.isSuccess();
    }

    public boolean isFailure() {
        return status.isFailure();
    }

    public boolean isCancel() {
        return status.isCancel();
    }

    public boolean isStageSuccess() {
        return status == BuildStatus.STAGE_SUCCESS;
    }

    public boolean isTriggerReviewing() {
        return status == BuildStatus.TRIGGER_REVIEWING;
    }

    public boolean isReadyToRun() {
        return status.isReadyToRun();
    }
}
