package cd.casic.pipeline.store.api.container;

import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.pipeline.store.pojo.app.ContainerAppVersion;
import cd.casic.pipeline.store.pojo.app.ContainerAppVersionCreate;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Tag(name = "OP_CONTAINER_APP_VERSION", description = "OP-容器-编译环境版本")
@RestController
@RequestMapping("/op/pipeline/container/app/version")
public interface OpContainerAppVersionResource {

    @Operation(summary = "添加编译环境版本")
    @PostMapping("/")
    CommonResult<Boolean> addContainerAppVersion(
            @Parameter(description = "容器编译环境版本请求实体", required = true)
            ContainerAppVersionCreate containerAppVersionRequest
    );

    @Operation(summary = "根据ID删除编译环境版本")
    @DeleteMapping("/{id}")
    CommonResult<Boolean> deleteContainerAppVersionById(
            @Parameter(description = "编译环境版本ID", required = true)
            @PathVariable("id")
            int id
    );

    @Operation(summary = "更新编译环境版本")
    @PutMapping("/{id}")
    CommonResult<Boolean> updateContainerAppVersion(
            @Parameter(description = "编译环境版本ID", required = true)
            @PathVariable("id")
            int id,
            @Parameter(description = "容器编译环境版本请求实体", required = true)
            ContainerAppVersionCreate containerAppVersionRequest
    );

    @Operation(summary = "根据appId获取所有编译环境版本信息")
    @GetMapping("/list/{appId}")
    CommonResult<List<ContainerAppVersion>> listContainerAppVersionsByAppId(
            @Parameter(description = "编译环境ID", required = true)
            @PathVariable("appId")
            int appId
    );

    @Operation(summary = "根据ID获取编译环境版本信息")
    @GetMapping("/{id}")
    CommonResult<ContainerAppVersion> getContainerAppVersionById(
            @Parameter(description = "编译环境版本ID", required = true)
            @PathVariable("id")
            int id
    );
}